@@ -37,10 +37,15 @@ import pygments.lexers
 import pygments.formatters
 import json
 import morph
+import logging
 
 from .i18n import _
 from . import pyaml
 
+#------------------------------------------------------------------------------
+
+log = logging.getLogger(__name__)
+
 #------------------------------------------------------------------------------
 def mkdirp(path):
   if os.path.isdir(path):
@@ -115,7 +120,9 @@ def formatify_yaml(content, contentType):
 #------------------------------------------------------------------------------
 def formatify(content, contentType):
   lexer = getLexer(content, contentType)
-  if isinstance(lexer, pygments.lexers.XmlLexer):
+  log.debug('formatifying content-type %r (lexer %r)', contentType, lexer)
+  if isinstance(lexer, (pygments.lexers.XmlLexer, pygments.lexers.LassoXmlLexer)) \
+      or ( contentType and ( '/xml' in contentType or '+xml' in contentType ) ):
     return formatify_xml(content, contentType)
   if isinstance(lexer, pygments.lexers.JsonLexer):
     return formatify_json(content, contentType)
@@ -199,9 +206,7 @@ class LoggingRequestHandler(BaseHTTPServer.BaseHTTPRequestHandler):
     LoggingRequestHandler.REQUESTNUM += 1
     self.rid = LoggingRequestHandler.REQUESTNUM
     self.pid = os.getpid()
-    if self.options.verbose:
-      print >>self.options.errput, \
-        _('[  ] connection from client: {}:{}', *client_address)
+    log.info('connection from client: %s:%r', *client_address)
     BaseHTTPServer.BaseHTTPRequestHandler.__init__(self, request, client_address, server)
 
   #----------------------------------------------------------------------------
@@ -308,9 +313,9 @@ class StreamLogger(Logger):
     self.stream.write('---\n')
     meta = dict(msg)
     if 'client' in meta:
-      meta['client'] = ':'.join(meta['client'])
+      meta['client'] = ':'.join([str(el) for el in meta['client']])
     if 'server' in meta:
-      meta['server'] = ':'.join(meta['server'])
+      meta['server'] = ':'.join([str(el) for el in meta['server']])
     data = dict(meta=meta, rline=str(rLine), headers=dict(headers), content=body)
     yaml.dump(data, self.stream, default_flow_style=False)
     self.stream.write('\n')
@@ -326,8 +331,10 @@ class ReplayServer(object):
       hdrs = idict(record['headers'])
       if 'client' in msg:
         msg['client'] = msg['client'].split(':')
+        msg['client'][1] = int(msg['client'][1])
       if 'server' in msg:
         msg['server'] = msg['server'].split(':')
+        msg['server'][1] = int(msg['server'][1])
       self.logger.logMessage(msg, record['rline'], hdrs, record['content'])
 
 #------------------------------------------------------------------------------
